@@ -1,8 +1,5 @@
 package XML::Parser::ClinicalTrials::Study;
-{
-  $XML::Parser::ClinicalTrials::Study::VERSION = '1.20140111';
-}
-
+$XML::Parser::ClinicalTrials::Study::VERSION = '1.20150818';
 use 5.010;
 
 use constant PREFIX => 'XML::Parser::ClinicalTrials::Study';
@@ -145,11 +142,11 @@ XML::Parser::ClinicalTrials::Study - XML parser/representation for ClinicalTrial
 
 =head1 SYNOPSIS
 
-    use File::Slurp;
+    use File::Slurper 'read_text';
     use XML::Parser::ClinicalTrials::Study;
 
     # XML file downloaded from clinicaltrials.gov
-    my $xml   = read_file( 'NCT00003095.xml', binmode => ':utf8' );
+    my $xml   = read_text( 'NCT00003095.xml' );
     my $study = XML::Parser::ClinicalTrials::Study->new( xml => $xml );
 
 
